This is the repository for the RPNet package, a deep learning model for automatic P-wave first motion determination (Han et al., 2025).

The run_RPNet.py script predicts P-wave polarity from SAC or MSEED files using the RPNet model and automatically generates input files for SKHASH (Skoumal et al., 2024), a Python software based on HASH (Hardebeck and Shearer, 2002, 2003).

The pretrained model files can be downloaded from the google drive link in GitHub.

SKHASH (Skoumal et al., 2024): https://code.usgs.gov/esc/SKHASH
